@@ -58,8 +58,8 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
                                                 "pump.io/tryit.html</a>")
                                          + "<br><br>"
                                          + tr("If you need help: %1")
-                                           .arg("<a href=\"https://github.com/"
-                                                "e14n/pump.io/wiki/User-Guide\">"
+                                           .arg("<a href=\"https://pumpio.readthedocs.org"
+                                                "/en/latest/userguide.html\">"
                                                 + tr("Pump.io User Guide")
                                                 + "</a>"),
                                          this);
