@@ -69,11 +69,12 @@ private:
 
     QHBoxLayout *idLayout;
     QLabel *userIDIconLabel;
-    QLabel *userIDLabel;
-    QLineEdit *userIDLineEdit;
+    QLabel *userIdLabel;
+    QLineEdit *userIdLineEdit;
 
     QPushButton *getVerifierButton;
 
+    QFrame *separatorLine;
 
     QLabel *helpMessage2Label;
 
