@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -77,62 +77,79 @@ ASActivity::ASActivity(QVariantMap activityMap,
 
 
     // Audience: To
-    QVariantMap postToMap;
-    foreach (QVariant postToVariant, activityMap.value("to").toList())
+    QVariantMap aToMap;
+    foreach (QVariant toVariant, activityMap.value("to").toList())
     {
-        postToMap = postToVariant.toMap();
+        aToMap = toVariant.toMap();
 
-        QString toId = postToMap.value("id").toString();
+        QString toId = aToMap.value("id").toString();
         if (toId == "http://activityschema.org/collection/public")
         {
-            toString += "<b>" + tr("Public") + "</b>, ";
+            recipientsToString += "<b>" + tr("Public") + "</b>, ";
         }
         else
         {
-            QString displayName = postToMap.value("displayName").toString().trimmed();
+            QString displayName = aToMap.value("displayName").toString().trimmed();
             // If name's empty, and ID is from a person
             if (displayName.isEmpty() && toId.startsWith("acct:"))
             {
                 displayName = "&lt;" + ASPerson::cleanupId(toId) + "&gt;";
             }
-            displayName = MiscHelpers::fixLongName(displayName);
+#ifdef SHOWWRONGTOCC
+            if (displayName.isEmpty()) // if STILL empty, some weirdness is there
+            {
+                displayName = "-?-";
+            }
+#endif
             if (!displayName.isEmpty())
             {
-                toString += "<a href=\"" + postToMap.value("url").toString() + "\">"
-                            + displayName + "</a>, ";
+                recipientsToString += "<a href=\""
+                                      + aToMap.value("url").toString() + "\">"
+                                      + displayName + "</a>, ";
             }
 
             recipientsIdList.append(toId);
         }
     }
-    toString.remove(-2, 2); // remove last comma and space
+    recipientsToString.remove(-2, 2); // remove last comma and space
 
 
-    // and CC
-    QVariantMap postCCMap;
-    foreach (QVariant postCCVariant, activityMap.value("cc").toList())
+    // and Cc
+    QVariantMap aCcMap;
+    foreach (QVariant ccVariant, activityMap.value("cc").toList())
     {
-        postCCMap = postCCVariant.toMap();
+        aCcMap = ccVariant.toMap();
 
-        QString ccId = postCCMap.value("id").toString();
+        QString ccId = aCcMap.value("id").toString();
         if (ccId == "http://activityschema.org/collection/public")
         {
-            ccString += "<b>" + tr("Public") + "</b>, ";
+            recipientsCcString += "<b>" + tr("Public") + "</b>, ";
         }
         else
         {
-            QString displayName = postCCMap.value("displayName").toString().trimmed();
-            displayName = MiscHelpers::fixLongName(displayName);
+            QString displayName = aCcMap.value("displayName").toString().trimmed();
+            // If name's empty, and ID is from a person
+            if (displayName.isEmpty() && ccId.startsWith("acct:"))
+            {
+                displayName = "&lt;" + ASPerson::cleanupId(ccId) + "&gt;";
+            }
+#ifdef SHOWWRONGTOCC
+            if (displayName.isEmpty()) // if STILL empty, for some reason...
+            {
+                displayName = "-?-";
+            }
+#endif
             if (!displayName.isEmpty())
             {
-                ccString += "<a href=\"" + postCCMap.value("url").toString() + "\">"
-                          + displayName + "</a>, ";
+                recipientsCcString += "<a href=\""
+                                      + aCcMap.value("url").toString() + "\">"
+                                      + displayName + "</a>, ";
             }
 
             recipientsIdList.append(ccId);
         }
     }
-    ccString.remove(-2, 2);
+    recipientsCcString.remove(-2, 2);
 
 
     qDebug() << "ASActivity created" << this->id;
@@ -202,12 +219,12 @@ QString ASActivity::getContent()
 
 QString ASActivity::getToString()
 {
-    return this->toString;
+    return this->recipientsToString;
 }
 
 QString ASActivity::getCCString()
 {
-    return this->ccString;
+    return this->recipientsCcString;
 }
 
 QStringList ASActivity::getRecipientsIdList()
