@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -169,8 +169,11 @@ ASObject::ASObject(QVariantMap objectMap,
     lastCommentsList = objectMap.value("replies").toMap().value("items").toList();
     lastSharesList = objectMap.value("shares").toMap().value("items").toList();
 
+    proxiedUrls = false;
+
     // Get URL for likes; first, proxyURL if it exists
-    likesUrl = objectMap.value("likes").toMap().value("pump_io").toMap().value("proxyURL").toString();
+    likesUrl = objectMap.value("likes").toMap().value("pump_io").toMap()
+                                               .value("proxyURL").toString();
     // If still empty, get regular URL (that means the post is in the same server we are)
     if (likesUrl.isEmpty())
     {
@@ -178,11 +181,16 @@ ASObject::ASObject(QVariantMap objectMap,
     }
 
     // Get URL for comments; first, proxyURL if it exists
-    commentsUrl = objectMap.value("replies").toMap().value("pump_io").toMap().value("proxyURL").toString();
+    commentsUrl = objectMap.value("replies").toMap().value("pump_io").toMap()
+                                                    .value("proxyURL").toString();
     if (commentsUrl.isEmpty()) // If still empty, get regular URL
     {
         commentsUrl = objectMap.value("replies").toMap().value("url").toString();
     }
+    else
+    {
+        this->proxiedUrls = true;
+    }
 
     // FIXME: get sharesUrl...
 
@@ -196,6 +204,13 @@ ASObject::~ASObject()
 
 
 
+void ASObject::updateAuthorFromPerson(ASPerson *person)
+{
+    this->asAuthor->updateDataFromPerson(person);
+}
+
+
+
 /////// Getters
 
 ASPerson *ASObject::author()
@@ -337,13 +352,18 @@ QString ASObject::getDeletedOnString()
     QString deletedOnString;
     if (!this->deleted.isEmpty())
     {
-        deletedOnString = tr("Deleted on %1")
-                          .arg(Timestamp::localTimeDate(this->deleted));
+        deletedOnString = this->makeDeletedOnString(this->deleted);
     }
 
     return deletedOnString;
 }
 
+QString ASObject::makeDeletedOnString(QString deletionTime)
+{
+    return tr("Deleted on %1").arg(Timestamp::localTimeDate(deletionTime));
+}
+
+
 QString ASObject::isLiked()
 {
     return this->liked;
@@ -420,6 +440,11 @@ QString ASObject::getSharesCount()
     return this->sharesCount;
 }
 
+bool ASObject::hasProxiedUrls()
+{
+    return this->proxiedUrls;
+}
+
 QVariantList ASObject::getLastLikesList()
 {
     return this->lastLikesList;
@@ -460,7 +485,16 @@ QVariantMap ASObject::getInReplyTo()
     return this->inReplyToMap;
 }
 
+QString ASObject::getInReplyToId()
+{
+    return inReplyToMap.value("id").toString();
+}
 
+
+/*
+ * This version should be deprecated soon -- WIP
+ *
+ */
 QString ASObject::personStringFromList(QVariantList variantList, int count)
 {
     QString personString;
@@ -501,6 +535,75 @@ QString ASObject::personStringFromList(QVariantList variantList, int count)
     }
 
 
+    return personString;
+} // deprecating... WIP
+
+
+
+QVariantMap ASObject::simplePersonMapFromList(QVariantList variantList)
+{
+    QVariantMap map;
+
+    // Read the list in reverse order:
+
+    for (int position = variantList.size() - 1; position >= 0; --position)
+    {
+        QVariantMap itemMap = variantList.at(position).toMap();
+
+        QString id = ASPerson::cleanupId(itemMap.value("id").toString());
+        QString name = itemMap.value("displayName").toString();
+        if (name.isEmpty())
+        {
+            name = id; // fallback
+        }
+        QString profileUrl = itemMap.value("url").toString();
+
+        ASObject::addOnePersonToSimpleMap(id, name, profileUrl,
+                                          &map);
+    }
+
+    return map;
+}
+
+
+void ASObject::addOnePersonToSimpleMap(QString personId, QString personName,
+                                       QString personUrl, QVariantMap *personMap)
+{
+    personMap->insert(personId, "<a href=\"" + personUrl + "\">"
+                                + personName + "</a>");
+}
+
+
+QString ASObject::personStringFromSimpleMap(QVariantMap personMap,
+                                            int totalCount)
+{
+    QString personString;
+
+    foreach (QString key, personMap.keys())
+    {
+        personString.append(personMap.value(key).toString() + ", ");
+    }
+
+    int remainingCount = totalCount - personMap.keys().length();
+
+    // Add "and $COUNT other"
+    if (remainingCount > 0)
+    {
+        if (remainingCount == 1)
+        {
+            personString.append(tr("and one other"));
+        }
+        else
+        {
+            personString.append(tr("and %1 others").arg(remainingCount));
+        }
+    }
+    else
+    {
+        // Remove last comma and space
+        personString.remove(-2, 2);
+    }
+
     return personString;
 }
 
