@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -39,6 +39,8 @@ public:
                       QObject *parent = 0);
     ~ASObject();
 
+    void updateAuthorFromPerson(ASPerson *person);
+
     ASPerson *author();
 
     QString getId();
@@ -54,6 +56,7 @@ public:
 
     QString getDeletedTime();
     QString getDeletedOnString();
+    static QString makeDeletedOnString(QString deletionTime);
     QString isLiked();
 
     QString getTitle();
@@ -73,6 +76,7 @@ public:
     QString getLikesCount();
     QString getCommentsCount();
     QString getSharesCount();
+    bool hasProxiedUrls();
 
     QVariantList getLastLikesList();
     QVariantList getLastCommentsList();
@@ -84,10 +88,18 @@ public:
 
     QVariantMap getOriginalObject();
     QVariantMap getInReplyTo();
+    QString getInReplyToId();
 
+    // This one to deprecate
     static QString personStringFromList(QVariantList variantList,
                                         int count=-1);
 
+    static QVariantMap simplePersonMapFromList(QVariantList variantList);
+    static void addOnePersonToSimpleMap(QString personId, QString personName,
+                                        QString personUrl, QVariantMap *personMap);
+    static QString personStringFromSimpleMap(QVariantMap personMap,
+                                             int totalCount);
+
     static bool canDisplayObject(QString objectType);
 
 
@@ -95,6 +107,7 @@ signals:
 
 public slots:
 
+
 private:
     ASPerson *asAuthor;
 
@@ -136,6 +149,7 @@ private:
     QString likesUrl;
     QString commentsUrl;
     QString sharesUrl;
+    bool proxiedUrls;
 
     QVariantMap originalObjectMap;
     QVariantMap inReplyToMap;
