@@ -50,6 +50,8 @@ public:
 
     QString getTooltipInfo();
 
+    QString getOutboxLink();
+
     bool isFollowed();
 
     //int getFollowingCount();
@@ -72,6 +74,8 @@ private:
     QString avatar;
     QString url;
 
+    QString outboxLink;
+
     QString followed;
     //int followingCount;
     //int followersCount;
