@@ -77,7 +77,9 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
     explanationLabel = new QLabel(tr("Select people from the list on the left.\n"
                                      "You can drag them with the mouse, click or "
                                      "double-click on them, or select them and "
-                                     "use the button below."),
+                                     "use the button below.",
+                                     "ON THE LEFT should change to ON THE "
+                                     "RIGHT in RTL languages"),
                                   this);
     explanationLabel->setWordWrap(true);
 
