@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -59,13 +59,13 @@ public:
 
 signals:
     void audienceSelected(QString selectorType,
-                          QStringList contactsList);
+                          QStringList contactsList,
+                          QStringList urlsList);
 
 
 public slots:
-    void copyToSelected(QIcon contactIcon,
-                        QString contactString);
-
+    void copyToSelected(QIcon contactIcon, QString contactString,
+                        QString contactUrl);
     void setAudience();
 
 
