@@ -307,7 +307,7 @@ void AvatarButton::browseUserMessages()
     this->globalObj->browseUserMessages(this->authorId,
                                         this->authorName,
                                         this->icon(),
-                                        this->authorOutbox + "/major");
+                                        this->authorOutbox + "/major"); // TMP!
 }
 
 
