@@ -24,6 +24,7 @@
 #include <QToolButton>
 #include <QMenu>
 #include <QMessageBox>
+#include <QScrollArea>
 
 #include <QDebug>
 
@@ -64,6 +65,7 @@ public slots:
     void followUser();
     void unfollowUser();
     void sendMessageToUser();
+    void browseUserMessages();
 
     void redrawAvatar(QString avatarUrl, QString avatarFilename);
 
@@ -77,6 +79,7 @@ private:
     QAction *avatarMenuProfileAction;
     QAction *avatarMenuFollowAction;
     QAction *avatarMenuMessageAction;
+    QAction *avatarMenuBrowseAction;
 
     int iconWidth;
 
@@ -84,6 +87,7 @@ private:
     QString authorName;
     QString authorUrl;
     QString authorAvatarUrl;
+    QString authorOutbox;
 
     bool authorFollowed;
 };
