@@ -24,14 +24,15 @@ ColorPicker::ColorPicker(QString description,
                          QString initialColorString,
                          QWidget *parent) : QWidget(parent)
 {
-    descriptionLabel = new QLabel(description);
+    descriptionLabel = new QLabel(description, this);
     descriptionLabel->setWordWrap(true);
+    descriptionLabel->setAlignment(Qt::AlignTop);
 
-    checkBox = new QCheckBox();
+    checkBox = new QCheckBox(this);
 
     buttonPixmap = QPixmap(32, 32);
 
-    button = new QPushButton(tr("Change"));
+    button = new QPushButton(tr("Change"), this);
     button->setIconSize(QSize(32, 32));
     button->setDisabled(true); // Disabled initially
     connect(button, SIGNAL(clicked()),
@@ -107,7 +108,8 @@ QString ColorPicker::getCurrentColor()
 
 void ColorPicker::changeColor()
 {
-    QColor newColor = QColorDialog::getColor(currentColor, this);
+    QColor newColor = QColorDialog::getColor(currentColor, this,
+                                             tr("Choose a color"));
 
     if (newColor.isValid())
     {
