@@ -33,10 +33,8 @@ Comment::Comment(PumpController *pumpController,
     QSizePolicy sizePolicy;
     sizePolicy.setHeightForWidth(false);
     sizePolicy.setWidthForHeight(false);
-    //sizePolicy.setHorizontalPolicy(QSizePolicy::MinimumExpanding);
-    //sizePolicy.setVerticalPolicy(QSizePolicy::Maximum);
     sizePolicy.setHorizontalPolicy(QSizePolicy::Ignored);
-    sizePolicy.setVerticalPolicy(QSizePolicy::Preferred);
+    sizePolicy.setVerticalPolicy(QSizePolicy::Maximum); // Previously QSizePolicy::Preferred
     this->setSizePolicy(sizePolicy);
     this->setMinimumSize(10, 10); // Ensure something's visible at any time
     this->setMaximumHeight(4096);
@@ -45,7 +43,7 @@ Comment::Comment(PumpController *pumpController,
     this->commentId = commentObject->getId();
     this->objectType = commentObject->getType();
 
-    QString commentAuthorId = commentObject->author()->getId();;
+    this->commentAuthorId = commentObject->author()->getId();
     if (commentAuthorId == pController->currentUserId())
     {
         commentIsOwn = true; // Comment is ours!
@@ -476,6 +474,7 @@ void Comment::likeComment(QString clickedLink)
 
     this->pController->likePost(this->commentId,
                                 this->objectType,
+                                this->commentAuthorId,
                                 this->commentIsLiked);
     this->fixLikeLabelText();
 }
@@ -553,7 +552,7 @@ void Comment::deleteComment()
     }
     else
     {
-        qDebug() << "Confirmation canceled, not deleting the comment";
+        qDebug() << "Confirmation cancelled, not deleting the comment";
     }
 }
 
