@@ -91,7 +91,9 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
 
 
     this->commentComposer = new Composer(this->globalObj,
-                                         false); // forPublisher = false
+                                         false, // forPublisher = false
+                                         this);
+
     this->commentComposer->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
     this->commentComposer->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     this->commentComposer->setSizePolicy(QSizePolicy::MinimumExpanding,
@@ -109,7 +111,7 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
 
 
     // Info label about sending status
-    this->statusInfoLabel = new QLabel();
+    this->statusInfoLabel = new QLabel(this);
     statusInfoLabel->setAlignment(Qt::AlignCenter);
     statusInfoLabel->setWordWrap(true);
     showAllFont.setPointSize(showAllFont.pointSize() + 1);
@@ -119,7 +121,8 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
     this->commentButton = new QPushButton(QIcon::fromTheme("mail-send",
                                                            QIcon(":/images/button-post.png")),
                                           tr("Comment",
-                                             "Infinitive verb"));
+                                             "Infinitive verb"),
+                                          this);
     commentButton->setToolTip("<b></b>"
                               + tr("You can press Control+Enter to send "
                                    "the comment with the keyboard"));
@@ -128,7 +131,8 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
 
     this->cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                           QIcon(":/images/button-cancel.png")),
-                                         tr("Cancel"));
+                                         tr("Cancel"),
+                                         this);
     cancelButton->setToolTip("<b></b>"
                              + tr("Press ESC to cancel the comment "
                                   "if there is no text"));
@@ -348,7 +352,7 @@ void CommenterBlock::updateAvatarFollowStates()
 }
 
 
-void CommenterBlock::updateShowAllLink()
+void CommenterBlock::updateShowAllLink(bool firstTry)
 {
     QString showAllString;
     if (allCommentsShown)
@@ -357,8 +361,15 @@ void CommenterBlock::updateShowAllLink()
     }
     else
     {
-        showAllString = tr("Show all %1 comments")
-                        .arg(this->currentCommentCount);
+        if (firstTry)
+        {
+            showAllString = tr("Check for comments");
+        }
+        else
+        {
+            showAllString = tr("Show all %1 comments")
+                            .arg(this->currentCommentCount);
+        }
     }
 
     // Small trick to avoid a bug where the link stops having appropriate mouse pointer
@@ -372,6 +383,18 @@ void CommenterBlock::updateShowAllLink()
 }
 
 
+/*
+ * Disable the "check for comments" link when there's no valid comment URL,
+ * by setting a clear message instead. Simply disabling the widget wouldn't
+ * make the link look disabled.
+ *
+ */
+void CommenterBlock::disableShowAllLink()
+{
+    this->showAllCommentsLinkLabel->setText(tr("Comments are not available"));
+}
+
+
 
 void CommenterBlock::adjustCommentsWidth()
 {
@@ -477,7 +500,17 @@ void CommenterBlock::setFullMode(QString initialText)
     this->cancelButton->show();
 
     this->commentComposer->setFocus();
-    this->commentComposer->append(initialText);
+    if (!initialText.isEmpty())
+    {
+        this->commentComposer->append(initialText);
+        // Alternative way, would insert anywhere, has other problems
+        // this->commentComposer->insertHtml(initialText);
+
+        // Delete extra newline after the quote
+        this->commentComposer->moveCursor(QTextCursor::End); // Otherwise could delete other characters
+        this->commentComposer->textCursor().deletePreviousChar();
+    }
+
     this->fullMode = true;
 }
 
