@@ -57,7 +57,8 @@ public:
 
     void updateFuzzyTimestamps();
     void updateAvatarFollowStates();
-    void updateShowAllLink();
+    void updateShowAllLink(bool firstTry=false);
+    void disableShowAllLink();
 
     void adjustCommentsWidth();
     void adjustCommentsHeight();
