@@ -21,7 +21,8 @@
 #include "composer.h"
 
 
-Composer::Composer(GlobalObject *globalObject, bool forPublisher)
+Composer::Composer(GlobalObject *globalObject, bool forPublisher,
+                   QWidget *parent) : QTextEdit(parent)
 {
     this->globalObj = globalObject;
     this->forPublisher = forPublisher;
@@ -169,6 +170,8 @@ Composer::Composer(GlobalObject *globalObject, bool forPublisher)
     popupTableView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     popupTableView->setAlternatingRowColors(true);
     popupTableView->setSelectionBehavior(QAbstractItemView::SelectRows);
+    popupTableView->setSelectionMode(QAbstractItemView::SingleSelection);
+    popupTableView->setEditTriggers(QAbstractItemView::NoEditTriggers);
     nickCompleter->setPopup(popupTableView);
 
     mainLayout = new QHBoxLayout();
@@ -258,6 +261,9 @@ void Composer::requestCompletion(QString partialNick)
     int rowHeight = popupTableView->rowHeight(0) + 4;
     popupTableView->setMinimumHeight(rows * rowHeight);
 
+    // Popup might get disabled at some point when Composer is used in a Post
+    popupTableView->setEnabled(true);
+
     nickCompleter->complete(QRect(this->cursorRect().x(),
                                   this->cursorRect().y() + 24,
                                   tableWidth, 1));
@@ -324,7 +330,7 @@ void Composer::keyPressEvent(QKeyEvent *event)
 {
     //qDebug() << "Composer::keyPressEvent()";
 
-    // Allow canceling/accepting the autocompletion popup
+    // Allow cancelling/accepting the autocompletion popup
     if (this->nickCompleter->popup()->isVisible())
     {
         if (event->key() == Qt::Key_Enter
@@ -349,7 +355,7 @@ void Composer::keyPressEvent(QKeyEvent *event)
         qDebug() << "Escape was pressed";
         if (this->toPlainText().isEmpty())
         {
-            qDebug() << "There was no text, canceling post";
+            qDebug() << "There was no text, cancelling post";
             this->cancelPost();
         }
     }
@@ -692,10 +698,11 @@ void Composer::makeQuote()
     if (!selectedText.isEmpty())
     {
         this->textCursor().removeSelectedText();
-        this->insertHtml("<br />"
+        this->insertHtml("&nbsp; "
                          "<blockquote>&ldquo;" + selectedText
                          + "&rdquo;</blockquote>"
                            "<br />");
+        this->textCursor().deletePreviousChar(); // Delete undesired extra newline
     }
     // FIXME: Qt's HTML changes <blockquote> into its own formatting
     // so other clients and the web UI might not display it as other people's blockquote's
@@ -844,14 +851,22 @@ void Composer::pasteAsPlaintext()
  */
 void Composer::insertCompletedNick(QModelIndex nickData)
 {
-    QTextCursor textCursor = this->textCursor();
-    textCursor.select(QTextCursor::WordUnderCursor);
-    textCursor.removeSelectedText();
-
     QString nickId = nickData.data(Qt::UserRole + 1).toString();
     QString nickName = nickData.data().toString();
     QString nickUrl = nickData.data(Qt::UserRole + 2).toString();
 
+    // Abort if there's no ID; this can happen if the ID column is clicked
+    if (nickId.isEmpty())
+    {
+        qDebug() << "*** AUTOCOMPLETER: ID IS EMPTY! (clicked 2nd column?)";
+
+        return;
+    }
+
+    QTextCursor textCursor = this->textCursor();
+    textCursor.select(QTextCursor::WordUnderCursor);
+    textCursor.removeSelectedText();
+
     this->insertHtml("<a href=\"" + nickUrl + "\">"
                      + nickName + "</a>");
     this->makeNormal();
@@ -873,7 +888,7 @@ void Composer::cancelPost()
 
     if (this->document()->isEmpty())
     {
-        cancelConfirmed = 0; // Canceling doesn't need confirmation if it's empty
+        cancelConfirmed = 0; // Cancelling doesn't need confirmation if it's empty
     }
     else
     {
@@ -893,6 +908,6 @@ void Composer::cancelPost()
         // emit signal to make Publisher go back to minimum mode
         emit editingCancelled();
 
-        qDebug() << "Post canceled";
+        qDebug() << "Post cancelled";
     }
 }
