@@ -63,7 +63,7 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     // Page 1, general options
     this->generalOptionsLayout = new QFormLayout();
 
-    updateIntervalSpinbox = new QSpinBox();
+    updateIntervalSpinbox = new QSpinBox(this);
     updateIntervalSpinbox->setRange(2, 99); // 2-99 min
     updateIntervalSpinbox->setSuffix(" "+ tr("minutes"));
     updateIntervalSpinbox->setValue(updateInterval);
@@ -72,40 +72,43 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
 
 
     // ------------------------------------------------
-    QFrame *lineFrame1 = new QFrame();
+    QFrame *lineFrame1 = new QFrame(this);
     lineFrame1->setFrameStyle(QFrame::HLine);
     generalOptionsLayout->addRow(lineFrame1);
 
 
-    tabsPositionCombobox = new QComboBox();
+    tabsPositionCombobox = new QComboBox(this);
     tabsPositionCombobox->addItem(QIcon::fromTheme("arrow-up"),
                                   tr("Top"));
     tabsPositionCombobox->addItem(QIcon::fromTheme("arrow-down"),
                                   tr("Bottom"));
     tabsPositionCombobox->addItem(QIcon::fromTheme("arrow-left"),
-                                  tr("Left side"));
+                                  tr("Left side",
+                                     "tabs on left side/west; RTL not affected"));
     tabsPositionCombobox->addItem(QIcon::fromTheme("arrow-right"),
-                                  tr("Right side"));
+                                  tr("Right side",
+                                     "tabs on right side/east; RTL not affected"));
     tabsPositionCombobox->setCurrentIndex(tabsPosition);
     generalOptionsLayout->addRow(tr("&Tabs position"),
                                  tabsPositionCombobox);
 
 
-    tabsMovableCheckbox = new QCheckBox();
+    tabsMovableCheckbox = new QCheckBox(this);
     tabsMovableCheckbox->setChecked(tabsMovable);
     generalOptionsLayout->addRow(tr("&Movable tabs"),
                                  tabsMovableCheckbox);
 
 
     // ------------------------------------------------
-    QFrame *lineFrame2 = new QFrame();
+    QFrame *lineFrame2 = new QFrame(this);
     lineFrame2->setFrameStyle(QFrame::HLine);
     generalOptionsLayout->addRow(lineFrame2);
 
 
     proxyConfigButton = new QPushButton(QIcon::fromTheme("preferences-system-network",
                                                          QIcon(":/images/button-configure.png")),
-                                        tr("Pro&xy Settings"));
+                                        tr("Pro&xy Settings"),
+                                        this);
     connect(proxyConfigButton, SIGNAL(clicked()),
             proxyDialog, SLOT(show()));
     generalOptionsLayout->addRow(tr("Network configuration"),
@@ -113,14 +116,15 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
 
     filterEditorButton = new QPushButton(QIcon::fromTheme("view-filter",
                                                           QIcon(":/images/button-filter.png")),
-                                         tr("Set Up F&ilters"));
+                                         tr("Set Up F&ilters"),
+                                         this);
     connect(filterEditorButton, SIGNAL(clicked()),
             this, SIGNAL(filterEditorRequested()));
     generalOptionsLayout->addRow(tr("Filtering rules"),
                                  filterEditorButton);
 
 
-    generalOptionsWidget = new QWidget();
+    generalOptionsWidget = new QWidget(this);
     generalOptionsWidget->setLayout(generalOptionsLayout);
 
 
@@ -128,13 +132,17 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     // Page 2, fonts
     this->fontOptionsLayout = new QVBoxLayout();
     fontPicker1 = new FontPicker(tr("Post Titles"),
-                                 globalObj->getPostTitleFont());
+                                 globalObj->getPostTitleFont(),
+                                 this);
     fontPicker2 = new FontPicker(tr("Post Contents"),
-                                 globalObj->getPostContentsFont());
+                                 globalObj->getPostContentsFont(),
+                                 this);
     fontPicker3 = new FontPicker(tr("Comments"),
-                                 globalObj->getCommentsFont());
+                                 globalObj->getCommentsFont(),
+                                 this);
     fontPicker4 = new FontPicker(tr("Minor Feeds"),
-                                 globalObj->getMinorFeedFont());
+                                 globalObj->getMinorFeedFont(),
+                                 this);
     // FIXME: more for "Timestamps" or something else?
     // FIXME: add a "base font size" option
 
@@ -144,7 +152,7 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     fontOptionsLayout->addWidget(fontPicker4);
     fontOptionsLayout->addStretch(1);
 
-    fontOptionsWidget = new QWidget();
+    fontOptionsWidget = new QWidget(this);
     fontOptionsWidget->setLayout(fontOptionsLayout);
 
 
@@ -242,11 +250,8 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
 
     showDeletedCheckbox = new QCheckBox(this);
     showDeletedCheckbox->setChecked(globalObj->getShowDeleted());
-    /*
-    timelinesOptionsLayout->addRow("Show frame of deleted posts", // Not translatable for now
-                                   showDeletedCheckbox);          // FIXME 1.3.2
-    */
-    showDeletedCheckbox->hide(); // TMP, FIXME 1.3.2
+    timelinesOptionsLayout->addRow(tr("Show information for deleted posts"), // FIXME?
+                                   showDeletedCheckbox);
 
     hideDuplicatesCheckbox = new QCheckBox(this);
     hideDuplicatesCheckbox->setChecked(globalObj->getHideDuplicates());
@@ -339,12 +344,16 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     silentFollowsCheckbox->setChecked(globalObj->getSilentFollows());
     silentListsCheckbox = new QCheckBox(this);
     silentListsCheckbox->setChecked(globalObj->getSilentLists());
+    silentLikesCheckbox = new QCheckBox(this);
+    silentLikesCheckbox->setChecked(globalObj->getSilentLikes());
 
     privacyOptionsLayout = new QFormLayout();
     privacyOptionsLayout->addRow(tr("Don't inform followers when following someone"),
                                  silentFollowsCheckbox);
     privacyOptionsLayout->addRow(tr("Don't inform followers when handling lists"),
                                  silentListsCheckbox);
+    privacyOptionsLayout->addRow(tr("Inform only the author when liking things"),
+                                 silentLikesCheckbox);
 
     privacyOptionsWidget = new QWidget(this);
     privacyOptionsWidget->setLayout(privacyOptionsLayout);
@@ -365,6 +374,8 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
                                                               0).toInt());
     notificationOptionsLayout->addRow(tr("Notification Style"),
                                       notificationStyleCombobox);
+    connect(notificationStyleCombobox, SIGNAL(currentIndexChanged(int)),
+            this, SLOT(toggleNotificationDetails(int)));
 
     notificationsStatusLabel = new QLabel(this);
     notificationOptionsLayout->addRow("", // Empty label on left to align with right column
@@ -421,6 +432,9 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
                                                             0).toInt());
     systrayOptionsLayout->addRow(tr("System Tray Icon &Type"),
                                  systrayIconTypeCombobox);
+    connect(systrayIconTypeCombobox, SIGNAL(currentIndexChanged(int)),
+            this, SLOT(toggleCustomIconButton(int)));
+
 
     systrayCustomIconButton = new QPushButton(tr("S&elect..."), this);
     systrayIconLastUsedDir = QDir::homePath();
@@ -442,6 +456,10 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     systrayOptionsLayout->addRow(tr("Custom &Icon"),
                                  systrayCustomIconButton);
 
+    // Enable/disable initially based on loaded config
+    this->toggleCustomIconButton(systrayIconTypeCombobox->currentIndex());
+
+
     systrayHideCheckbox = new QCheckBox(this);
     systrayHideCheckbox->setChecked(globalObject->getHideInTray());
     systrayOptionsLayout->addRow(tr("Hide window on startup"),
@@ -453,12 +471,14 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     settings.endGroup();
 
 
+///////////////////////////////////////////////////////////////////////////////
+
 
     ///////////////////////////////////// List of categories and stacked widget
     categoriesListWidget = new QListWidget(this);
     categoriesListWidget->setSizePolicy(QSizePolicy::Preferred,
                                         QSizePolicy::MinimumExpanding);
-    categoriesListWidget->setMinimumWidth(100); // kinda TMP/FIXME
+    categoriesListWidget->setMinimumWidth(140); // kinda TMP/FIXME
 #if 0 // enable for large-icon-mode with text below
     categoriesListWidget->setViewMode(QListView::IconMode);
     categoriesListWidget->setFlow(QListView::TopToBottom);
@@ -564,11 +584,11 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     //// Set up main layout
     mainLayout = new QVBoxLayout();
     mainLayout->addLayout(topLayout, 10);
-    mainLayout->addSpacing(16);
+    mainLayout->addSpacing(8);
     mainLayout->addStretch(1);
     mainLayout->addWidget(dataDirectoryLabel);
-    mainLayout->addSpacing(16);
-    mainLayout->addStretch(1);
+    mainLayout->addSpacing(8);
+    mainLayout->addStretch(2);
     mainLayout->addLayout(buttonsLayout);
     this->setLayout(mainLayout);
 
@@ -588,6 +608,8 @@ ConfigDialog::~ConfigDialog()
 
 void ConfigDialog::syncNotifierOptions()
 {
+    this->toggleNotificationDetails(notificationStyleCombobox->currentIndex());
+
     this->fdNotifier->setNotificationOptions(notificationStyleCombobox->currentIndex(),
                                              notifyNewTLCheckbox->isChecked(),
                                              notifyHLTLCheckbox->isChecked(),
@@ -633,6 +655,13 @@ QString ConfigDialog::checkNotifications(int notificationStyle)
 }
 
 
+void ConfigDialog::setPublicPosts(bool value)
+{
+    this->publicPostsCheckbox->setChecked(value);
+    this->saveConfiguration(); // This might be overkill -- FIXME TMP
+}
+
+
 
 //////////////////////////////////////////////////////////////////////////////
 ///////////////////////////////// SLOTS //////////////////////////////////////
@@ -750,8 +779,11 @@ void ConfigDialog::saveConfiguration()
                       this->silentFollowsCheckbox->isChecked());
     settings.setValue("silentLists",
                       this->silentListsCheckbox->isChecked());
+    settings.setValue("silentLikes",
+                      this->silentLikesCheckbox->isChecked());
     this->globalObj->syncPrivacySettings(this->silentFollowsCheckbox->isChecked(),
-                                         this->silentListsCheckbox->isChecked());
+                                         this->silentListsCheckbox->isChecked(),
+                                         this->silentLikesCheckbox->isChecked());
 
 
     // Notifications
@@ -835,6 +867,33 @@ void ConfigDialog::showDemoNotification(int notificationStyle)
 }
 
 
+void ConfigDialog::toggleNotificationDetails(int currentOption)
+{
+    bool state = true;
+    if (currentOption == 2) // No notifications; disable details so it's clearer
+    {
+        state = false;
+    }
+
+    this->notifyNewTLCheckbox->setEnabled(state);
+    this->notifyHLTLCheckbox->setEnabled(state);
+    this->notifyNewMWCheckbox->setEnabled(state);
+    this->notifyHLMWCheckbox->setEnabled(state);
+}
+
+
+void ConfigDialog::toggleCustomIconButton(int currentOption)
+{
+    bool state = false;
+    if (currentOption == 3) // Enable only for last option, "Custom icon"
+    {
+        state = true;
+    }
+
+    this->systrayCustomIconButton->setEnabled(state);
+}
+
+
 //////////////////////////////////////////////////////////////////////////////
 /////////////////////////////// PROTECTED ////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
