@@ -65,6 +65,7 @@ public:
 
     void syncNotifierOptions();
     QString checkNotifications(int notificationStyle);
+    void setPublicPosts(bool value);
 
 
 signals:
@@ -76,6 +77,8 @@ public slots:
     void saveConfiguration();
     void pickCustomIconFile();
     void showDemoNotification(int notificationStyle);
+    void toggleNotificationDetails(int currentOption);
+    void toggleCustomIconButton(int currentOption);
 
 
 protected:
@@ -173,6 +176,7 @@ private:
 
     QCheckBox *silentFollowsCheckbox;
     QCheckBox *silentListsCheckbox;
+    QCheckBox *silentLikesCheckbox;
 
 
 
