@@ -146,6 +146,10 @@ ContactCard::ContactCard(PumpController *pumpController,
                                     this);
     connect(openProfileAction, SIGNAL(triggered()),
             this, SLOT(openProfileInBrowser()));
+    if (this->contactUrl.isEmpty()) // Disable if there is no URL
+    {
+        openProfileAction->setDisabled(true);
+    }
 
     sendMessageAction = new QAction(QIcon::fromTheme("document-edit",
                                                      QIcon(":/images/button-edit.png")),
