@@ -69,6 +69,7 @@ public slots:
 
     void openProfileInBrowser();
     void setMessagingModeForContact();
+    void browseContactPosts();
 
     void redrawAvatar(QString avatarUrl, QString avatarFilename);
 
@@ -86,6 +87,7 @@ private:
     QMenu *optionsMenu;
     QAction *openProfileAction;
     QAction *sendMessageAction;
+    QAction *browsePostsAction;
     QMenu *addToListMenu;
 
 
@@ -95,6 +97,7 @@ private:
     QString contactId;
     QString contactUrl;
     QString contactAvatarUrl;
+    QString contactOutbox;
 };
 
 #endif // CONTACTCARD_H
