@@ -41,7 +41,8 @@ ContactManager::ContactManager(PumpController *pumpController,
     mainLayout->setAlignment(Qt::AlignTop);
 
 
-    QString webfingerHelpMessage = tr("username@server.org or https://server.org/username");
+    QString webfingerHelpMessage = tr("username@server.org or "
+                                      "https://server.org/username");
 
     topLayout = new QHBoxLayout();
     enterAddressLabel = new QLabel(tr("&Enter address to follow:"), this);
@@ -74,7 +75,7 @@ ContactManager::ContactManager(PumpController *pumpController,
     topLayout->addWidget(followButton);
 
     mainLayout->addLayout(topLayout);
-    mainLayout->addSpacing(12);
+    mainLayout->addSpacing(4);
 
 
     // Widgets for list of 'following' and 'followers'
@@ -96,13 +97,18 @@ ContactManager::ContactManager(PumpController *pumpController,
 
 
     // Widget for the list of 'person lists'
-    this->listsManager = new ListsManager(this->pController);
+    this->listsManager = new ListsManager(this->pController, this);
     listsScrollArea = new QScrollArea(this);
     listsScrollArea->setWidget(this->listsManager);
     listsScrollArea->setWidgetResizable(true);
     listsScrollArea->setFrameStyle(QFrame::NoFrame);
 
 
+    // Widget for the list of site users; users from your own server
+    this->siteUsersList = new SiteUsersList(this->pController,
+                                            this->globalObj,
+                                            this);
+
     // Options menu
     optionsMenu = new QMenu("*options-menu*", this);
     optionsMenu->addAction(QIcon::fromTheme("view-refresh",
@@ -153,9 +159,14 @@ ContactManager::ContactManager(PumpController *pumpController,
                       QIcon::fromTheme("preferences-contact-list",
                                        QIcon(":/images/button-edit.png")),
                       "*lists*");
+    tabWidget->addTab(siteUsersList,
+                      QIcon::fromTheme("system-users",
+                                       QIcon(":/images/no-avatar.png")),
+                      tr("&Neighbors"));
     tabWidget->setCornerWidget(this->optionsButton);
 
 
+
     this->followersCount = 0;
     this->followingCount = 0;
     this->listsCount = 0;
@@ -180,13 +191,17 @@ ContactManager::~ContactManager()
 void ContactManager::setTabLabels()
 {
     this->tabWidget->setTabText(0, tr("Follo&wers")
-                                   + QString(" (%1)").arg(this->followersCount));
+                                   + QString(" (%1)")
+                                     .arg(QLocale::system()
+                                          .toString(this->followersCount)));
 
     this->tabWidget->setTabText(1, tr("Followin&g")
-                                   + QString(" (%1)").arg(this->followingCount));
+                                   + QString(" (%1)")
+                                     .arg(QLocale::system()
+                                          .toString(this->followingCount)));
 
     this->tabWidget->setTabText(2, tr("&Lists")
-                                + QString(" (%1)").arg(this->listsCount));
+                                + QString(" (%1)").arg(this->listsCount)); // Not worth localizing
 }
 
 
@@ -213,7 +228,7 @@ void ContactManager::exportContactsToFile(QString listType)
                                                     + suggestedFilename,
                                                     "").trimmed();
 
-    if (filename.isEmpty()) // If dialog canceled, do nothing
+    if (filename.isEmpty()) // If dialog was cancelled, do nothing
     {
         return;
     }
