@@ -42,6 +42,7 @@
 #include "contactlist.h"
 #include "listsmanager.h"
 #include "globalobject.h"
+#include "siteuserslist.h"
 
 
 
@@ -63,8 +64,8 @@ signals:
 
 public slots:
     void setContactListsContents(QString listType,
-                                QVariantList contactList,
-                                int totalReceivedCount);
+                                 QVariantList contactList,
+                                 int totalReceivedCount);
     void setListsListContents(QVariantList listsList);
 
     void changeFollowingCount(int difference);
@@ -104,6 +105,7 @@ private:
     QScrollArea *listsScrollArea;
     int listsCount;
 
+    SiteUsersList *siteUsersList;
 
     QPushButton *optionsButton;
     QMenu *optionsMenu;
