@@ -96,7 +96,8 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
 
     /////////////////////////////////////////////////////////////////// PRIVACY
     this->syncPrivacySettings(settings.value("silentFollows", false).toBool(),
-                              settings.value("silentLists", true).toBool());
+                              settings.value("silentLists", true).toBool(),
+                              settings.value("silentLikes", false).toBool());
 
 
     ///////////////////////////////////////////////////////////// NOTIFICATIONS
@@ -362,10 +363,12 @@ bool GlobalObject::getShowCharacterCounter()
 
 
 // Privacy options
-void GlobalObject::syncPrivacySettings(bool silentFollows, bool silentLists)
+void GlobalObject::syncPrivacySettings(bool silentFollows, bool silentLists,
+                                       bool silentLikes)
 {
     this->silentFollowing = silentFollows;
     this->silentListsHandling = silentLists;
+    this->silentLiking = silentLikes;
 }
 
 bool GlobalObject::getSilentFollows()
@@ -378,6 +381,11 @@ bool GlobalObject::getSilentLists()
     return this->silentListsHandling;
 }
 
+bool GlobalObject::getSilentLikes()
+{
+    return this->silentLiking;
+}
+
 
 
 // Notification options
@@ -474,7 +482,7 @@ void GlobalObject::removeFromNickCompletionModel(QString id)
 
     foreach (QStandardItem *item, allNicks)
     {
-        qDebug() << item->data(Qt::UserRole + 1).toString();
+        //qDebug() << item->data(Qt::UserRole + 1).toString();
 
         if (item->data(Qt::UserRole + 1).toString() == id)
         {
