@@ -91,7 +91,7 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
                        "tooltip to appear.")
                     + "<br><br>");
     helpText.append(tr("If you're new to Pump.io, take a look at this guide:")
-                    + " <a href=\"https://github.com/e14n/pump.io/wiki/User-Guide\">"
+                    + " <a href=\"https://pumpio.readthedocs.org/en/latest/userguide.html\">"
                     + tr("Pump.io User Guide")
                     + "</a>");
 
@@ -138,7 +138,8 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
                        "as the Meanwhile. This is visible on the left side, "
                        "though it can be hidden. Here you'll see minor activities "
                        "done by everyone you follow, such as comment actions, "
-                       "liking posts or following people.")
+                       "liking posts or following people.",
+                       "LEFT SIDE should change to RIGHT SIDE on RTL languages")
                     + "<br>"
                     + tr("The sixth and seventh timelines are also minor "
                          "timelines, similar to the Meanwhile, but containing "
@@ -208,6 +209,10 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
                          "directly enter addresses of new contacts to "
                          "follow them.")
                     + "<br><br>"
+                    + tr("Under the 'Neighbors' tab you'll see some resources "
+                         "to find people, and have the option to browse the "
+                         "latest registered users from your server directly.")
+                    + "<br><br><br"
                     + tr("You can click on any avatars in the posts, the "
                          "comments, and the Meanwhile column, and you will get "
                          "a menu with several options, one of which is following "
@@ -275,20 +280,41 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
                        "instances of Dianara at the same time.")
                     + "<br><br>");
     helpText.append(tr("Use the --debug parameter to have extra information "
-                       "in your terminal window, about what the program is doing."));
+                       "in your terminal window, about what the program is doing.")
+                    + "<br><br>");
+    helpText.append(tr("If your server does not support HTTPS, you can use the "
+                       "--nohttps parameter.")
+                    + "<br><br><br>");
+
+    helpText.append(tr("Dianara offers a D-Bus interface that allows some "
+                       "control from other applications.")
+                    + " "
+                    + tr("The interface is at %1, and you can "
+                         "access it with tools such as %2 or %3. It "
+                         "offers methods like %4 and %5.")
+                      .arg("<b>org.nongnu.dianara</b>")
+                      .arg("<b>qdbus</b>").arg("<b>dbus-send</b>")
+                      .arg("<b>'toggle'</b>").arg("<b>'post'</b>")
+                    + "<br>"
+                    + tr("If you use an alternate configuration, with "
+                         "something like '--config otherconf', then the "
+                         "interface will be at org.nongnu.dianara_otherconf."));
+
 
     helpText.append("<br><br>");
 
     ///////////////////////////////////////////////////////////////// Help text
 
 
-    helpTextBrowser = new QTextBrowser();
+    helpTextBrowser = new QTextBrowser(this);
     helpTextBrowser->setReadOnly(true);
     helpTextBrowser->setOpenExternalLinks(true);
     helpTextBrowser->setText(helpText);
 
-    closeButton = new QPushButton(QIcon::fromTheme("window-close"),
-                                  tr("&Close"));
+    closeButton = new QPushButton(QIcon::fromTheme("window-close",
+                                                   QIcon(":/images/button-close.png")),
+                                  tr("&Close"),
+                                  this);
     connect(closeButton, SIGNAL(clicked()),
             this, SLOT(hide()));
 
