@@ -84,7 +84,8 @@ ImageViewer::ImageViewer(QString fileURI,
     infoLabel = new QLabel(imageDetails, this);
     infoLabel->setAlignment(Qt::AlignCenter);
 
-    closeButton = new QPushButton(QIcon::fromTheme("window-close"),
+    closeButton = new QPushButton(QIcon::fromTheme("window-close",
+                                                   QIcon(":/images/button-close.png")),
                                   tr("&Close"),
                                   this);
     connect(closeButton, SIGNAL(clicked()),
@@ -141,7 +142,8 @@ void ImageViewer::createContextMenu()
     connect(saveAction, SIGNAL(triggered()),
             this, SLOT(saveImage()));
 
-    this->closeAction = new QAction(QIcon::fromTheme("window-close"),
+    this->closeAction = new QAction(QIcon::fromTheme("window-close",
+                                                     QIcon(":/images/button-close.png")),
                                     tr("Close Viewer"),
                                     this);
     closeAction->setShortcut(QKeySequence(Qt::Key_Escape));
