@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -66,7 +66,7 @@ public slots:
     void enableDisableDeleteButtons();
 
     void showAddPersonDialog();
-    void addPerson(QIcon icon, QString contactString);
+    void addPerson(QIcon icon, QString contactString, QString contactUrl);
     void removePerson();
 
     void addPersonItemToList(QString personId, QString personName,
