@@ -58,21 +58,35 @@ int main(int argc, char *argv[])
 {
     QApplication dianaraApp(argc, argv);
     dianaraApp.setApplicationName("Dianara");
-    dianaraApp.setApplicationVersion("1.3.1");
+    dianaraApp.setApplicationVersion("1.3.2");
     dianaraApp.setOrganizationName("JanCoding");
     dianaraApp.setOrganizationDomain("jancoding.wordpress.com");
 
     std::cout << QString("Dianara v%1 - JanKusanagi 2012-2015\n"
-                         "http://jancoding.wordpress.com/dianara\n\n")
+                         "https://jancoding.wordpress.com/dianara\n\n")
                         .arg(dianaraApp.applicationVersion()).toStdString();
-    std::cout << QString("- Built with Qt v%1 on %2, %3\n")
-                 .arg(QT_VERSION_STR)
+
+    std::cout << QString("- Built with Qt v%1").arg(QT_VERSION_STR)
+                                               .toStdString();
+
+/*
+ * REPRODUCIBLEBUILD is defined via .pro file when SOURCE_DATE_EPOCH is
+ * defined in the build environment. This is used to avoid hardcoding
+ * timestamps and this way make the builds reproducible.
+ *
+ */
+#ifndef REPRODUCIBLEBUILD
+    std::cout << QString(" on %1, %2")
                  .arg(__DATE__)
                  .arg(__TIME__).toStdString();
+#endif
+    std::cout << "\n";
 
-    std::cout << QString("- Running with Qt v%1\n\n").arg(qVersion()).toStdString();
+    std::cout << QString("- Running with Qt v%1\n\n").arg(qVersion())
+                                                     .toStdString();
     std::cout.flush();
 
+
     // To make the mswin version of Dianara distributable as a standalone package
 #ifdef Q_OS_WIN
     dianaraApp.addLibraryPath("./plugins/");
@@ -85,6 +99,7 @@ int main(int argc, char *argv[])
     bool debugMode = false;
     bool nextParameterIsConfig = false;
     bool ignoreSslErrors = false;
+    bool nohttps = false;
 
     // Parse command line parameters
     if (!cmdLine.isEmpty())
@@ -98,27 +113,40 @@ int main(int argc, char *argv[])
                 std::cout << "\nHelp:\n";
                 std::cout << "    " << argv[0] << " [options]\n\n";
                 std::cout << "Options:\n";
-                std::cout << "    -c  --config [name]      Use a different "
+                std::cout << "    -c  --config [name]       Use a different "
                              "configuration file\n";
-                std::cout << "    -d  --debug              Show debug messages "
+                std::cout << "    -d  --debug               Show debug messages "
                              "in the terminal\n";
-                std::cout << "        --linkcolor=[color]  Set color for "
-                             "links, such as 'green' or '#00B500'\n";
-                std::cout << "        --ignoresslerrors    Ignore SSL errors "
-                             "(dangerous, use with care!)\n";
-                std::cout << "    -v  --version            Show version "
+                std::cout << "        --linkcolor=[color]   Set color for "
+                             "links, such as 'green' or '#00B500'\n"
+                             "\n";
+                std::cout << "        --nohttps             Use this if your "
+                             "server does not support HTTPS\n";
+                std::cout << "        --ignoresslerrors     Ignore SSL errors "
+                             "(dangerous, use with care!)\n"
+                             "\n";
+                std::cout << "    -v  --version             Show version "
                              "information and exit\n";
-                std::cout << "    -h  --help               Show this help and "
+                std::cout << "    -h  --help                Show this help and "
                              "exit\n";
                 std::cout << "\n";
 
                 return 0; // Exit to shell
             }
 
+
+            // Version info
             if (argument.startsWith("--version", Qt::CaseInsensitive)
              || argument.startsWith("-v", Qt::CaseInsensitive))
             {
                 // Version information already shown
+                std::cout << "\n"
+                             "You can get the latest stable version from "
+                             "http://dianara.nongnu.org and\n"
+                             "the latest development version from "
+                             "https://gitlab.com/dianara/dianara-dev"
+                             "\n\n";
+
                 return 0;
             }
 
@@ -150,17 +178,6 @@ int main(int argc, char *argv[])
                 std::cout << "Debug messages enabled\n";
             }
 
-            // Option to ignore SSL errors
-            if (argument.startsWith("--ignoresslerrors", Qt::CaseInsensitive))
-            {
-                ignoreSslErrors = true;
-                cmdLine.removeAll(argument);
-
-                std::cout << "*************************************\n"
-                             "*** WARNING: Ignoring SSL errors. ***\n"
-                             "***          This is insecure!    ***\n"
-                             "*************************************\n";
-            }
 
             // Option to set link color (useful in GTK environments)
             if (argument.startsWith("--linkcolor=", Qt::CaseInsensitive))
@@ -181,7 +198,31 @@ int main(int argc, char *argv[])
                     std::cout << "Invalid link color specified!\n";
                 }
             }
-        }
+
+
+            // Option to use non-https servers
+            if (argument.startsWith("--nohttps", Qt::CaseInsensitive))
+            {
+                nohttps = true;
+                cmdLine.removeAll(argument);
+
+                std::cout << "*** Using No-HTTPS mode\n";
+            }
+
+
+            // Option to ignore SSL errors
+            if (argument.startsWith("--ignoresslerrors", Qt::CaseInsensitive))
+            {
+                ignoreSslErrors = true;
+                cmdLine.removeAll(argument);
+
+                std::cout << "*************************************\n"
+                             "*** WARNING: Ignoring SSL errors. ***\n"
+                             "***          This is insecure!    ***\n"
+                             "*************************************\n";
+            }
+
+        } // End foreach
     }
 
 
@@ -203,31 +244,70 @@ int main(int argc, char *argv[])
 
 
     // Load translation files
-    QTranslator translator;
     // Get language from LANG environment variable or system's locale
     QString languageString = qgetenv("LANG");
     if (languageString.isEmpty())
     {
         languageString = QLocale::system().name();
     }
+
     QString languageFile;
-    languageFile = QString(":/translations/dianara_%1")
-                   .arg(languageString);
-    std::cout << "Using translation file: "
-              << languageFile.toStdString() << "\n";
+    bool languageLoaded;
 
-    translator.load(languageFile);
-    dianaraApp.installTranslator(&translator);
 
+    QTranslator translatorQt;
+    languageFile = QString("qt_%1").arg(languageString);
+    std::cout << "\n"
+              << "Using Qt translation "
+              << QLibraryInfo::location(QLibraryInfo::TranslationsPath).toStdString()
+              << "/" << languageFile.toStdString() << "... ";
+    languageLoaded = translatorQt.load(languageFile,
+                                       QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+    if (languageLoaded)
+    {
+        std::cout << "OK";
+        dianaraApp.installTranslator(&translatorQt);
+    }
+    else
+    {
+        std::cout << "Unavailable";
+    }
+
+
+    QTranslator translatorDianara;
+    languageFile = QString(":/translations/dianara_%1").arg(languageString);
+    std::cout << "\n"
+              << "Using program translation "
+              << languageFile.toStdString() << "... ";
+
+    languageLoaded = translatorDianara.load(languageFile);
+    if (languageLoaded)
+    {
+        std::cout << "OK";
+        dianaraApp.installTranslator(&translatorDianara);
+    }
+    else
+    {
+        std::cout << "Unavailable";
+    }
+
+
+    std::cout << "\n\n";
     std::cout.flush();
 
 
     MainWindow dianaraWindow;
+
     if (ignoreSslErrors)
     {
         dianaraWindow.enableIgnoringSslErrors();
     }
 
+    if (nohttps)
+    {
+        dianaraWindow.enableNoHttpsMode();
+    }
+
     dianaraWindow.toggleMainWindow(true);  // show(), firstTime=true
 
 
