@@ -52,6 +52,11 @@
 #include <QPainter>
 #include <QSessionManager>
 
+#ifdef QT_DBUS_LIB
+#include <QtDBus>
+#include "dbusinterface.h"
+#endif
+
 #include <QDebug>
 
 #include <iostream>
@@ -73,6 +78,7 @@
 #include "groupsmanager.h"
 #include "globalobject.h"
 #include "userposts.h"
+#include "firstrunwizard.h"
 
 
 class MainWindow : public QMainWindow
@@ -105,6 +111,7 @@ public:
     void saveSettings();
 
     void enableIgnoringSslErrors();
+    void enableNoHttpsMode();
 
     Post *findPostInTimelines(QString id, bool *ok);
 
@@ -175,6 +182,7 @@ public slots:
     void setTransientStatusMessage(QString message);
 
     void markAllAsRead();
+    void startPost(QString title="", QString content="");
     void refreshAllTimestamps();
     void adjustTimelineSizes();
 
@@ -192,6 +200,7 @@ public slots:
     void toggleActionsFeed();
 
 
+    void showFirstRunWizard();
     void visitWebSite();
     void visitBugTracker();
     void visitPumpGuide();
@@ -248,6 +257,7 @@ private:
     QAction *settingsConfigure;
 
     QAction *helpBasicHelp;
+    QAction *helpShowWizard;
     QAction *helpVisitWebsite;
     QAction *helpVisitBugTracker;
     QAction *helpVisitPumpGuide;
@@ -257,6 +267,7 @@ private:
     QAction *helpAbout;
     ////////////////////////////////////// End menus
 
+
     // Info label for the menu
     QHBoxLayout *menuInfoLayout;
     QWidget *menuInfoWidget;
@@ -342,12 +353,20 @@ private:
 
     Publisher *publisher;
 
+#ifdef QT_DBUS_LIB
+    DBusInterface *dbusInterface;
+#endif
+
 
     bool firstRun;
-    QString dataDirectory; // will have /images and /avatars
+    QString dataDirectory; // will have /images, /avatars, etc
     bool reallyQuitProgram;
     bool initializationComplete;
 
+    int postIdsToStore;
+
+
+    // Timer stuff
     int updateInterval;
     QTimer *updateTimer;
 
@@ -358,6 +377,7 @@ private:
     QTimer *userDidSomethingTimer;
     QTimer *delayedScrollTimer;
 
+    // Statusbar stuff
     QString oldStatusBarMessage;
     QString previousStatusMessageFromTimeline;
     QString previousStatusMessageFromMinorFeed;
