@@ -98,7 +98,8 @@ MinorFeed::MinorFeed(PumpController::requestTypes minorFeedType,
     MinorFeedItem *demoFeedItem = new MinorFeedItem(demoActivity,
                                                     false, // Not highlighted by filter
                                                     this->pController,
-                                                    this->globalObj);
+                                                    this->globalObj,
+                                                    this);
     demoFeedItem->setItemAsNew(false,
                                false); // Do not inform the feed
     this->itemsLayout->addWidget(demoFeedItem);
@@ -329,7 +330,7 @@ void MinorFeed::syncActivityWithTimelines(ASActivity *activity)
     if (activity->getVerb() == "favorite"
      || activity->getVerb() == "like")
     {
-        // FIXME: handle liking of comments (1.3.2)
+        // FIXME: handle liking of comments (1.3.3)
 
         if (ASObject::canDisplayObject(activity->object()->getType()))
         {
@@ -345,7 +346,7 @@ void MinorFeed::syncActivityWithTimelines(ASActivity *activity)
     if (activity->getVerb() == "unfavorite"
      || activity->getVerb() == "unlike")
     {
-        // FIXME: handle unliking of comments (1.3.2)
+        // FIXME: handle unliking of comments (1.3.3)
 
         if (ASObject::canDisplayObject(activity->object()->getType()))
         {
@@ -559,7 +560,8 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
             MinorFeedItem *newFeedItem = new MinorFeedItem(activity,
                                                            itemHighlightedByFilter,
                                                            this->pController,
-                                                           this->globalObj);
+                                                           this->globalObj,
+                                                           this);
             newFeedItem->setItemAsNew(itemIsNew,
                                       false); // Don't inform the feed
             if (itemIsNew)
