@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -50,20 +50,33 @@ public:
     ~MinorFeed();
 
     void clearContents();
+    void removeOldItems(int minimumToKeep);
+    void insertSeparator(int position);
     void markAllAsRead();
     void updateFuzzyTimestamps();
+    void syncActivityWithTimelines(ASActivity *activity);
 
 
 signals:
     void newItemsCountChanged(int itemCount, int highlightedCount);
-    void newItemsReceived(int itemCount, int highlightedCount);
+    void newItemsReceived(PumpController::requestTypes feedType,
+                          int itemCount, int highlightedCount,
+                          int filteredCount, int pendingForNextUpdate);
+
+    void objectUpdated(ASObject *object);
+    void objectLiked(QString objectId, QString objectType, QString actorId,
+                     QString actorName, QString actorUrl);
+    void objectUnliked(QString objectId, QString objectType, QString actorId);
+    void objectReplyAdded(ASObject *object);
+    void objectDeleted(ASObject *object);
 
 
 public slots:
     void updateFeed();
     void getMoreActivities();
     void setFeedContents(QVariantList activitiesList,
-                         QString previous, QString next);
+                         QString previous, QString next,
+                         int totalItemCount);
 
     void decreaseNewItemsCount(bool wasHighlighted);
 
@@ -73,19 +86,24 @@ public slots:
 private:
     QString prevLink;
     QString nextLink;
+    int fullFeedItemCount;
+    int pendingToReceiveNextTime;
 
     PumpController::requestTypes feedType;
-    int feedOffset;
+    int feedBatchItemCount;
+    bool firstLoad;
+    bool gettingNew;
 
     QString previousNewestActivityId;
     QList<MinorFeedItem *> itemsInFeed;
 
-    int newItemsCount;
-    int newHighlightedItemsCount;
+    int unreadItemsCount;
+    int highlightedItemsCount;
 
     QVBoxLayout *mainLayout;
     QVBoxLayout *itemsLayout;
-    QPushButton *getMoreButton;
+    QPushButton *getPendingButton;
+    QPushButton *getOlderButton;
 
     QFrame *separatorFrame;
 
