@@ -249,7 +249,8 @@ QString MiscHelpers::fileSizeString(QString fileURI)
 
 
     // Return with 0 padding and 2 decimal precision
-    return QString("%1 %2").arg(fileSize, 0, 'f', 2).arg(sizeUnit);
+    return QString("%1 %2").arg(QLocale::system().toString(fileSize, 'f', 2))
+                           .arg(sizeUnit);
 }
 
 
