@@ -31,14 +31,14 @@ FDNotifications::FDNotifications(QObject* parent) : QObject(parent)
     if (bus->isConnected())
     {
         QDBusReply<QStringList> busReply = bus->interface()->registeredServiceNames();
-        qDebug() << "Listing DBus services";
+        qDebug() << "Listing D-Bus services...";
         if (busReply.isValid())
         {
             foreach (QString serviceName, busReply.value())
             {
                 if (serviceName == "org.freedesktop.Notifications")
                 {
-                    qDebug() << "org.freedesktop.Notifications DBus service found!";
+                    qDebug() << "org.freedesktop.Notifications D-Bus service found!";
                     this->notificationsAvailable = true;
                 }
             }
@@ -46,7 +46,7 @@ FDNotifications::FDNotifications(QObject* parent) : QObject(parent)
     }
     else
     {
-        qDebug() << "DBus unavailable!";
+        qDebug() << "D-Bus unavailable!";
         notificationsAvailable = false;
     }
 #endif
@@ -156,7 +156,7 @@ void FDNotifications::showMessage(QString message)
     }
 
 
-    // Only when building with DBus support
+    // Only when building with D-Bus support
 #ifdef QT_DBUS_LIB
     message.replace("\n", "<br>"); // use HTML newlines
     // HTML newlines break notifications in Xfce; \n works, but is not actually
@@ -169,7 +169,7 @@ void FDNotifications::showMessage(QString message)
                                  "Notify");
 
 
-    // --- DBus Notify call ----------------------------------------------
+    // --- D-Bus Notify call ----------------------------------------------
     // method uint org.freedesktop.Notifications.Notify(QString app_name,
     // uint replaces_id, QString app_icon, QString summary, QString body,
     // QStringList actions, QVariantMap hints, int timeout)
