@@ -26,6 +26,7 @@
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QSpinBox>
+#include <QSlider>
 #include <QPushButton>
 #include <QAction>
 
@@ -48,8 +49,9 @@ signals:
 
 
 public slots:
+    void setToFirstPage();
+    void setToLastPage();
     void goToPage();
-    void goToLastPage();
 
     void onPageNumberEntered();
 
@@ -57,13 +59,21 @@ public slots:
 private:
     QVBoxLayout *mainLayout;
     QHBoxLayout *topLayout;
+    QHBoxLayout *middleLayout;
     QHBoxLayout *bottomLayout;
 
     QLabel *messageLabel;
     QSpinBox *pageNumberSpinbox;
     QLabel *rangeLabel;
+
+    QPushButton *firstButton;
+    QPushButton *lastButton;
+
+    QLabel *newerLabel;
+    QSlider *pageNumberSlider;
+    QLabel *olderLabel;
+
     QPushButton *goButton;
-    QPushButton *goToLastButton;
     QPushButton *closeButton;
 
     QAction *closeAction;
