@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -150,6 +150,7 @@ QStandardItem *PeopleWidget::createContactItem(ASPerson *contact)
     }
 
     item->setToolTip(contact->getTooltipInfo());
+    item->setData(contact->getUrl(), Qt::UserRole + 1);
 
     return item;
 }
@@ -247,7 +248,8 @@ void PeopleWidget::returnContact()
         }
 
         emit addButtonPressed(icon,
-                              allContactsListView->currentIndex().data().toString());
+                              allContactsListView->currentIndex().data().toString(), // name <id>
+                              allContactsListView->currentIndex().data(Qt::UserRole + 1).toString()); // URL
     }
 }
 
@@ -267,5 +269,6 @@ void PeopleWidget::returnClickedContact(QModelIndex modelIndex)
     }
 
     emit contactSelected(icon,
-                         modelIndex.data().toString());
+                         modelIndex.data().toString(),
+                         modelIndex.data(Qt::UserRole + 1).toString());
 }
