@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -53,8 +53,10 @@ public:
     enum WidgetType { EmbeddedWidget, StandaloneWidget };
 
 signals:
-    void contactSelected(QIcon contactIcon, QString contactString);
-    void addButtonPressed(QIcon contactIcon, QString contactString);
+    void contactSelected(QIcon contactIcon, QString contactString,
+                         QString contactUrl);
+    void addButtonPressed(QIcon contactIcon, QString contactString,
+                          QString contactUrl);
 
 
 public slots:
