@@ -339,7 +339,8 @@ Post::Post(ASActivity *activity,
         // -----
         postAuthorAvatarButton->addSeparatorToMenu();
 
-        this->closeAction = new QAction(QIcon::fromTheme("window-close"),
+        this->closeAction = new QAction(QIcon::fromTheme("window-close",
+                                                         QIcon(":/images/button-close.png")),
                                         tr("&Close"),
                                         this);
         connect(closeAction, SIGNAL(triggered()),
@@ -522,7 +523,8 @@ Post::Post(ASActivity *activity,
 #if 0
     if (standalone)
     {
-        this->closeButton = new QPushButton(QIcon::fromTheme("window-close"),
+        this->closeButton = new QPushButton(QIcon::fromTheme("window-close",
+                                                             QIcon(":/images/button-close.png")),
                                             tr("&Close"));
         closeButton->setFont(buttonsFont);
         closeButton->setSizePolicy(QSizePolicy::Ignored,
@@ -808,6 +810,18 @@ Post::Post(ASActivity *activity,
 
     rightColumnFrame->setLayout(rightColumnLayout);
 
+    if (standalone)
+    {
+        // Set link to "check for comments"
+        this->commenter->updateShowAllLink(true); // firstTry=true
+
+        this->updateBestCommentsUrl();
+        // If we still don't have a valid URL from our host, proxyURL or not..
+        if (!pController->urlIsInOurHost(this->postCommentsUrl))
+        {
+            this->commenter->disableShowAllLink();
+        }
+    }
 
     mainLayout = new QHBoxLayout();
     mainLayout->setContentsMargins(0, 0, 0, 0);   // Minimal margins
@@ -821,8 +835,8 @@ Post::Post(ASActivity *activity,
         if (globalObj->getPostExtendedShares())
         {
             // Add a vertical hint on left side, a line and a recycling symbol
-            QLabel *shareHintLabel = new QLabel(QString::fromUtf8("\342\231\272"),
-                                                this);
+            this->shareHintLabel = new QLabel(QString::fromUtf8("\342\231\272"),
+                                              this);
             shareHintLabel->setToolTip(this->postIsSharedLabel->toolTip());
             shareHintLabel->setAlignment(Qt::AlignBottom);
             shareHintLabel->setFrameStyle(QFrame::VLine);
@@ -1146,7 +1160,7 @@ void Post::setPostContents()
 
     // Add the text content of the post
     postText->setHtml(postMediaHtml
-                    + postTextContents);
+                      + postTextContents);
 
 
     this->setPostHeight();
@@ -1416,6 +1430,23 @@ void Post::setCommentsLabel(int commentsCount)
 }
 
 
+void Post::updateBestCommentsUrl()
+{
+    // If comments URL is in another server and not proxyed...
+    if (!pController->urlIsInOurHost(this->postCommentsUrl))
+    {
+        // Try to find the post in the 'ever seen' list
+        QString newCommentsUrl = pController->commentsUrlForPost(this->postId);
+
+        if (!newCommentsUrl.isEmpty())
+        {
+            qDebug() << "Found matching post; Updating comments URL...";
+            this->postCommentsUrl = newCommentsUrl;
+        }
+    }
+}
+
+
 
 
 /*
@@ -1671,7 +1702,8 @@ void Post::likePost(bool like)
 {
     qDebug() << "Post::likePost()" << (like ? "like" : "unlike");
 
-    this->pController->likePost(this->postId, this->postType, like);
+    this->pController->likePost(this->postId, this->postType,
+                                this->postAuthorId, like);
 
     this->fixLikeButton(like ? "true" : "false");
 
@@ -1761,17 +1793,7 @@ void Post::updateComment(QString commentId, QString commentText)
 
 void Post::getAllComments()
 {
-    // If comments URL is in another server and not proxyed...
-    if (!pController->urlIsInOurHost(this->postCommentsUrl))
-    {
-        // Try to find the post in the 'ever seen' list
-        QString newCommentsUrl = pController->commentsUrlForPost(this->postId);
-
-        if (!newCommentsUrl.isEmpty())
-        {
-            qDebug() << "Found matching post; Updating comments URL...";
-            this->postCommentsUrl = newCommentsUrl;
-        }
+    this->updateBestCommentsUrl();
 
         /* // Keeping this for the future
          * // to be used to copy over comments directly (TBD)
@@ -1790,7 +1812,7 @@ void Post::getAllComments()
             this->postCommentsUrl = alternatePost->commentsURL();
         }
         */
-    }
+
 
     this->pController->getPostComments(this->postCommentsUrl);
 }
@@ -1830,7 +1852,7 @@ void Post::sharePost()
     }
     else
     {
-        qDebug() << "Confirmation canceled, not sharing";
+        qDebug() << "Confirmation cancelled, not sharing";
     }
 }
 
@@ -1851,7 +1873,7 @@ void Post::unsharePost()
     }
     else
     {
-        qDebug() << "Confirmation canceled, will not unshare";
+        qDebug() << "Confirmation cancelled, will not unshare";
     }
 }
 
@@ -2172,7 +2194,7 @@ void Post::closeEvent(QCloseEvent *event)
     event->ignore(); // Event will be ignored anyway
 
 
-    // Check again; if it's still full, it means user canceled
+    // Check again; if it's still full, it means user cancelled
     if (!this->commenter->isFullMode()) // If not, accepted, so kill the post
     {
         this->hide();
