@@ -85,15 +85,19 @@ public:
     void refreshLikesInfo(int likesListSize, int likesCount);
     void setLikesLabel(int likesCount);
 
+
     QString commentsURL();
     void setComments(QVariantList commentsList);
     void appendComment(ASObject *comment);
     void setCommentsLabel(int commentsCount);
+    void updateBestCommentsUrl();
+
 
     QString sharesURL();
     void setShares(QVariantList sharesList, int sharesCount=-1);
     void setSharesLabel(int resharesCount);
 
+
     void setPostUnreadStatus();
     void setPostAsNew();
     void setPostAsRead(bool informTimeline=true);
@@ -209,6 +213,7 @@ private:
     QLabel *postToLabel;
     QLabel *postCCLabel;
     QLabel *postIsSharedLabel;
+    QLabel *shareHintLabel;
 
     HClabel *postLikesCountLabel;
     QLabel *postCommentsCountLabel;
