@@ -38,6 +38,7 @@
 
 #include "pumpcontroller.h"
 #include "mischelpers.h"
+#include "emailchanger.h"
 
 
 class ProfileEditor : public QWidget
@@ -61,6 +62,7 @@ public slots:
     void findAvatarFile();
     void saveProfile();
     void sendProfileData(QString newImageUrl = QString());
+    void enableSaveButton();
 
 
 protected:
@@ -73,6 +75,7 @@ private:
 
     QVBoxLayout *mainLayout;
     QFormLayout *topLayout;
+    QHBoxLayout *emailLayout;
     QHBoxLayout *avatarLayout;
     QHBoxLayout *bottomLayout;
 
@@ -82,6 +85,8 @@ private:
 
     QLabel *webfingerLabel;
     QLabel *emailLabel;
+    QPushButton *changeEmailButton;
+    EmailChanger *emailChanger;
 
     QLineEdit *fullNameLineEdit;
     QLineEdit *hometownLineEdit;
