@@ -65,6 +65,7 @@ Publisher::Publisher(PumpController *pumpController,
                                           "Meanwhile feed more informative");
 
     QFont titleFont;
+    titleFont.setPointSize(titleFont.pointSize() + 1);
     titleFont.setBold(true);
     titleLabel = new QLabel(tr("Title") + ":");
     titleLabel->setSizePolicy(QSizePolicy::Minimum,
@@ -120,7 +121,8 @@ Publisher::Publisher(PumpController *pumpController,
 
     // Composer
     composerBox = new Composer(this->globalObj,
-                               true); // forPublisher = true
+                               true,  // forPublisher = true
+                               this);
     composerBox->setSizePolicy(QSizePolicy::Minimum,
                                QSizePolicy::Minimum);
     connect(composerBox, SIGNAL(focusReceived()),
@@ -173,7 +175,8 @@ Publisher::Publisher(PumpController *pumpController,
 
     toSelectorButton = new QPushButton(QIcon::fromTheme("system-users",
                                                         QIcon(":/images/no-avatar.png")),
-                                     tr("To..."));
+                                       tr("To..."),
+                                       this);
     toSelectorButton->setToolTip("<b></b>"
                                  + tr("Select who will see this post"));
     toSelectorButton->setMenu(toSelectorMenu);
@@ -206,7 +209,8 @@ Publisher::Publisher(PumpController *pumpController,
 
     ccSelectorButton = new QPushButton(QIcon::fromTheme("system-users",
                                                         QIcon(":/images/no-avatar.png")),
-                                     tr("Cc..."));
+                                       tr("Cc..."),
+                                       this);
     ccSelectorButton->setToolTip("<b></b>"
                                  + tr("Select who will get a copy of this post"));
     ccSelectorButton->setMenu(ccSelectorMenu);
@@ -346,7 +350,7 @@ Publisher::Publisher(PumpController *pumpController,
 
     mainLayout->addWidget(toSelectorButton,    6, 0, 1, 1, Qt::AlignLeft);
     mainLayout->addWidget(ccSelectorButton,    6, 1, 1, 1, Qt::AlignLeft);
-    mainLayout->addWidget(addMediaButton,      6, 3, 1, 2, Qt::AlignLeft);
+    mainLayout->addWidget(addMediaButton,      6, 3, 1, 2, Qt::AlignCenter);
     mainLayout->addWidget(statusInfoLabel,     6, 5, 3, 2, Qt::AlignCenter);
     mainLayout->addWidget(postButton,          6, 7, 1, 1);
 
@@ -418,6 +422,31 @@ void Publisher::setEmptyMediaData()
 }
 
 
+/*
+ * Set title and content from the outside, for automation (dbus interface)
+ *
+ */
+void Publisher::setTitleAndContent(QString title, QString content)
+{
+    QString statusText;
+
+    if (this->titleLineEdit->text().isEmpty()
+     && this->composerBox->toPlainText().isEmpty())
+    {
+        this->titleLineEdit->setText(title.trimmed());
+        this->composerBox->setText(content.trimmed());
+
+        statusText = tr("Note started from another application."); // FIXME?
+    }
+    else
+    {
+        statusText = tr("Ignoring new note request from another application."); // TMP message FIXME
+    }
+
+    this->statusInfoLabel->setText(statusText);
+}
+
+
 void Publisher::updatePublicFollowersLabels()
 {
     QString toString;
@@ -988,7 +1017,28 @@ void Publisher::startMessageForContact(QString id, QString name, QString url)
  */
 void Publisher::addNickToRecipients(QString id, QString name, QString url)
 {
-    this->audienceSelectorTo->copyToSelected(QIcon::fromTheme("user-identity",
+    // If for some reason a name is received without an ID, do nothing
+    if (id.trimmed().isEmpty())
+    {
+        qDebug() << "Trying to add a nick to recipients without an ID!"
+                 << name << " - " << url;
+        return;
+    }
+
+    /* TMP/FIXME: Until audience can be modified when editing, To/Cc buttons
+     * are disabled, and so must be the nick autocompletion. Not actually
+     * disabled, but nick won't be added to the audience lists, since it
+     * wouldn't really do anything.
+     *
+     */
+    if (editingMode)
+    {
+        qDebug() << "Publisher: Can't modify audience in EDITING mode";
+        return;
+    }
+
+
+    this->audienceSelectorTo->copyToSelected(QIcon::fromTheme("user-identity", // FIXME
                                                               QIcon(":/images/no-avatar.png")),
                                              QString("%1 <%2>").arg(name).arg(id),
                                              url);
@@ -1553,13 +1603,16 @@ void Publisher::updateProgressBar(qint64 sent, qint64 total)
     this->uploadProgressBar->setValue(sent);
 
     this->uploadProgressBar->setToolTip(tr("%1 KiB of %2 KiB uploaded")
-                                        .arg(sent / 1024)
-                                        .arg(total / 1024));
+                                        .arg(QLocale::system()
+                                             .toString(sent / 1024))
+                                        .arg(QLocale::system()
+                                             .toString(total / 1024)));
 }
 
 
 void Publisher::updateCharacterCounter()
 {
     int charCount = composerBox->textCursor().document()->characterCount() - 1;
-    this->charCounterLabel->setText(QString("%1").arg(charCount));
+    this->charCounterLabel->setText(QString("%1")
+                                    .arg(QLocale::system().toString(charCount)));
 }
