@@ -81,6 +81,7 @@ public:
         FollowingListRequest,
         FollowersListRequest,
         ListsListRequest,
+        SiteUserListRequest,
         CreatePersonListRequest,
         DeletePersonListRequest,
         PersonListRequest,
@@ -141,6 +142,8 @@ public:
     bool needsProxyPassword();
     void setProxyPassword(QString password);
 
+    void updateApiUrls();
+
     void setPostsPerPageMain(int ppp);
     void setPostsPerPageOther(int ppp);
 
@@ -149,6 +152,8 @@ public:
     void setUserCredentials(QString userId);
     QString currentUserId();
     QString currentUsername();
+    QString currentServerScheme();
+    QString currentServerUrl();
     QString currentFollowersUrl();
     int currentFollowersCount();
     int currentFollowingCount();
@@ -169,6 +174,7 @@ public:
     void notifyImageFailed(QString imageUrl);
 
     void getContactList(QString listType, int offset=0);
+    void getSiteUserList();
     bool userInFollowing(QString contactId);
     void updateInternalFollowingIdList(QStringList idList);
     void removeFromInternalFollowingList(QString id);
@@ -200,6 +206,8 @@ public:
                                    QString contentTypeString="application/json");
 
     QByteArray prepareJSON(QVariantMap jsonVariantMap);
+    QVariantMap parseJSON(QByteArray rawData, bool *parsedOk);
+
 
     QNetworkReply *uploadFile(QString filename, QString contentType,
                               requestTypes uploadType = UploadFileRequest);
@@ -219,9 +227,11 @@ public:
 
     void setIgnoreSslErrors(bool state);
     void setIgnoreSslInImages(bool state);
+    void setNoHttpsMode();
 
     void setSilentFollows(bool state);
     void setSilentLists(bool state);
+    void setSilentLikes(bool state);
 
     void updatePostsEverSeen(QVariantMap postMap);
     QVariantMap getPostsEverSeen();
@@ -239,6 +249,7 @@ signals:
                          QString email);
     void contactListReceived(QString listType, QVariantList contactList,
                              int totalReceivedCount);
+    void siteUserListReceived(QVariantList contactList, int totalItems);
     void contactFollowed(ASPerson *contact);
     void contactUnfollowed(ASPerson *contact);
     void followingListChanged();
@@ -260,6 +271,7 @@ signals:
     void userTimelineReceived(QVariantList postList, QString previousLink,
                               QString nextLink, int totalItems,
                               QString url);
+    void userTimelineFailed();
 
     void likesReceived(QVariantList likesList, QString originatingPostURL);
     void commentsReceived(QVariantList commentsList, QString originatingPostURL);
@@ -323,7 +335,7 @@ public slots:
 
     void updatePost(QString id, QString type, QString content, QString title);
 
-    void likePost(QString postID, QString postType, bool like);
+    void likePost(QString postId, QString postType, QString authorId, bool like);
 
     void addComment(QString comment, QString postID, QString postType);
     void updateComment(QString id, QString content);
@@ -357,6 +369,7 @@ private:
     QString serverURL;
     QString apiBaseUrl;
     QString apiFeedUrl;
+    QString serverScheme;
 
     bool proxyUsesAuth;
 
@@ -404,6 +417,7 @@ private:
 
     bool silentFollows;
     bool silentListsHandling;
+    bool silentLikes;
 };
 
 #endif // PUMPCONTROLLER_H
