@@ -42,7 +42,7 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     QVariantMap demoAuthorData;
     demoAuthorData.insert("displayName",    "Demo User");
     demoAuthorData.insert("id",             "demo@somepump.example");
-    demoAuthorData.insert("url",            "http://jancoding.wordpress.com/dianara");
+    demoAuthorData.insert("url",            "https://jancoding.wordpress.com/dianara");
     demoAuthorData.insert("location",       demoLocationData);
     demoAuthorData.insert("summary",        "I am not a real user");
 
@@ -53,8 +53,8 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     demoObjectData.insert("objectType",     "note");
     demoObjectData.insert("id",             "demo-post-id");
 
-    // Show date/time when Dianara v1.3.0 was released
-    demoObjectData.insert("published",      "2015-05-01T18:00:00Z");
+    // Show date/time when Dianara v1.3.2 was released
+    demoObjectData.insert("published",      "2015-10-31T17:00:00Z");
 
 
     QSettings settings; // FIXME: kinda tmp, until posts have "unread" status, etc.
@@ -100,9 +100,9 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
                                    "extra information.")
                               + "<br><br>"
 
-                              + "<a href=\"http://jancoding.wordpress.com/dianara\">"
+                              + "<a href=\"https://jancoding.wordpress.com/dianara\">"
                               + tr("Dianara's blog") + "</a><br><br>"
-                                "<a href=\"https://github.com/e14n/pump.io/wiki/User-Guide\">"
+                                "<a href=\"https://pumpio.readthedocs.org/en/latest/userguide.html\">"
                               + tr("Pump.io User Guide")
                               + "</a>"
                               + "<br><br>");
@@ -243,6 +243,20 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
             this, SLOT(goToNextPage()));
 
 
+    // Set reversed icons for bottom buttons if RTL language causes reversed layout
+    if (qApp->layoutDirection() == Qt::RightToLeft)
+    {
+        this->firstPageButton->setIcon(QIcon::fromTheme("go-last",
+                                                        QIcon(":/images/button-next.png")));
+        this->previousPageButton->setIcon(QIcon::fromTheme("go-next",
+                                                           QIcon(":/images/button-next.png")));
+        this->nextPageButton->setIcon(QIcon::fromTheme("go-previous",
+                                                       QIcon(":/images/button-previous.png")));
+    }
+
+
+
+
     ///// Layout
     postsLayout = new QVBoxLayout();
     postsLayout->setContentsMargins(0, 0, 0, 0);
@@ -250,6 +264,8 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     // Setting alignment of this layout to AlignTop caused all posts to be
     // compressed at the top when there were a lot of them; removed
 
+
+
     bottomLayout = new QHBoxLayout();
     bottomLayout->addSpacing(2);
     bottomLayout->addWidget(firstPageButton,    3);
@@ -345,10 +361,7 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     }
     else
     {
-        this->infoLabel->setText("<big><b>"
-                                 + tr("Requesting...")
-                                 + "</b></big>");
-        this->infoLabel->show();
+        this->showMessage(tr("Requesting..."));
     }
 
 
@@ -357,6 +370,9 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     connect(pController, SIGNAL(followingListChanged()),
             this, SLOT(updateAvatarFollowStates()));
 
+    // Disable buttons initially, until something is received
+    this->disablePaginationButtons();
+
     qDebug() << "TimeLine created";
 }
 
@@ -440,8 +456,7 @@ void TimeLine::clearTimeLineContents(bool showMessage)
 
     if (showMessage)
     {
-        this->infoLabel->setText("<big><b>" + tr("Loading...") + "</b></big>");
-        this->infoLabel->show();
+        this->showMessage(tr("Loading..."));
     }
 
     qApp->processEvents(); // So GUI gets updated
@@ -555,22 +570,26 @@ void TimeLine::updateCurrentPageNumber()
 {
     int currentPage = this->getCurrentPage();
     int totalPages = this->getTotalPages();
+    QString currentPageString = QLocale::system().toString(currentPage);
+    QString totalPagesString = QLocale::system().toString(totalPages);
+    QString totalPostsString = QLocale::system()
+                               .toString(this->fullTimelinePostCount);
 
     this->currentPageButton->setText(QString("%1 / %2")
-                                     .arg(currentPage)
-                                     .arg(totalPages));
+                                     .arg(currentPageString)
+                                     .arg(totalPagesString));
     // The shortcut needs to be set each time the text is changed
     currentPageButton->setShortcut(QKeySequence("Ctrl+G"));
 
     this->currentPageButton->setToolTip(tr("Page %1 of %2.")
-                                        .arg(currentPage)
-                                        .arg(totalPages)
+                                        .arg(currentPageString)
+                                        .arg(totalPagesString)
                                         + "<br>"
                                         + tr("Showing %1 posts per page.")
                                           .arg(this->postsPerPage)
                                         + "<br>"
                                         + tr("%1 posts in total.")
-                                          .arg(this->fullTimelinePostCount)
+                                          .arg(totalPostsString)
                                         + "<hr>"
                                           "<b><i>"
                                         + tr("Click here or press Control+G to "
@@ -596,6 +615,17 @@ void TimeLine::syncPostsPerPage()
     }
 }
 
+void TimeLine::disablePaginationButtons()
+{
+    this->firstPageButton->setDisabled(true);
+
+    this->previousPageButton->setDisabled(true);
+    this->currentPageButton->setDisabled(true);
+    this->nextPageButton->setDisabled(true);
+
+    this->getNewPendingButton->setDisabled(true);
+}
+
 
 
 
@@ -692,6 +722,15 @@ QFrame *TimeLine::getSeparatorFrame()
 }
 
 
+void TimeLine::showMessage(QString message)
+{
+    this->infoLabel->setText("<big><b>"
+                             + message
+                             + "</b></big>");
+    this->infoLabel->show();
+}
+
+
 
 /*****************************************************************************/
 /*****************************************************************************/
@@ -769,6 +808,7 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
                                                + "\n"
                                                + tr("Click here to receive "
                                                     "them now."));
+            this->getNewPendingButton->setEnabled(true);
             this->getNewPendingButton->show();
         }
     }
@@ -991,8 +1031,6 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
 
     if (postListSize > 0)
     {
-        this->updateCurrentPageNumber();
-
         // Resize the posts, but only the ones added in this update
         this->resizePosts(postsInsertedThisTime);
     }
@@ -1025,10 +1063,7 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
 
     if (postsInTimeline.length() == 0)
     {
-        this->infoLabel->setText("<big><b>"
-                                 + tr("There are no posts")
-                                 + "</b></big>");
-        this->infoLabel->show();
+        this->showMessage(tr("There are no posts"));
         this->postsWidget->hide();
     }
     else
@@ -1039,6 +1074,9 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
 
     // Enable timeline again, since everything is added and drawn
     this->setEnabled(true);
+    this->firstPageButton->setEnabled(true);
+    this->currentPageButton->setEnabled(true);
+    this->updateCurrentPageNumber(); // Even when not needed, will re-enable some buttons
 
     qDebug() << "setTimeLineContents() /END";
 }
@@ -1135,6 +1173,7 @@ void TimeLine::setPostsDeletedFromMinorFeed(ASObject *object)
     {
         if (post->getObjectId() == object->getId())
         {
+            post->setPostAsRead(true); // Just in case, and notifying timeline
             post->setPostDeleted(object->getDeletedOnString());
         }
     }
@@ -1245,6 +1284,11 @@ void TimeLine::goToFirstPage()
         this->setDisabled(true); // Disable soon, to avoid wrong clicks
     }
 
+    // Disable pagination buttons to avoid double-clicking problems, in case
+    // the whole timeline isn't disabled (whenever we're in the first page)
+    this->disablePaginationButtons();
+    // The ones that make sense will be re-enabled later
+
     /*
      * If this is the favorites timeline, previousPageLink will be empty,
      * which means the first posts at offset 0 will be loaded anyway
