@@ -63,6 +63,7 @@ public:
     int getTotalPosts();
     void updateCurrentPageNumber();
     void syncPostsPerPage();
+    void disablePaginationButtons();
 
     void resizePosts(QList<Post *> postsToResize, bool resizeAll=false);
 
@@ -77,6 +78,8 @@ public:
 
     QFrame *getSeparatorFrame();
 
+    void showMessage(QString message);
+
 
 signals:
     void scrollTo(QAbstractSlider::SliderAction sliderAction);
